#############################################################################
# LFS Handicapping Interface by Krayy
#############################################################################
# Ver 1.0.1 11-08-09 Initial release
# Ver 1.0.5 22-08-09 Major changes to functionality
#                    Added Save/Load code to store and retreive values
#                    Multiple column support for up to 32 players
#                    Changed button names to be unique
# Ver 1.0.6 27/12/09 Updated to be compatible with LFSLapper v5.918
#############################################################################

CatchEvent OnLapperStart()
	CifRegisterModule("Info", "Grid", "1.01");

	### Create and Initialise RaceGridOrder array ####
	GlobalVar $RaceGridOrder;
	FOR ( $i = 0; $i < 32; $i = $i + 1 )
		$RaceGridOrder[$i] = 0;
	ENDFOR
EndCatchEvent

CatchEvent OnMSO( $userName, $text ) # Player event
	$idxOfFirstSpace = indexOf( $text, " ");
	IF( $idxOfFirstSpace == -1 ) THEN
	  $command = $text;
	  $argv = "";
	ELSE
	  $command = subStr( $text,0,$idxOfFirstSpace );
	  $argv = trim( subStr( $text,$idxOfFirstSpace ) );
	ENDIF

	SWITCH( $command )
		CASE "!grid":
			DoCifInfoGrid(0,0);
   		BREAK;
	ENDSWITCH
EndCatchEvent

CatchEvent OnREO ( $NumP, $ReqI, $currRaceOrder ) # Lapper event
	globalMsg ( "OnReorder " . $NumP . ":" . $ReqI . " = " . $currRaceOrder);
	# Split the comma seperated list of PLIDs and transpose that to the RaceGridOrder global array
	$RO = SplitTOArray(  $currRaceOrder , "," );
#	dumpvar($RO);
	FOR ( $i=0; $i < 32; $i = $i + 1 )
		$RaceGridOrder[$i] = ToNum($RO[$i]);
	ENDFOR
EndCatchEvent

Sub DoCifInfoGrid($KeyFlags,$id)
	# Set default values for the module - these MUST be the same as the main Do function name
	$cifGroupName="Info";
	$cifModuleName="Grid";
	$DialogPrefix = "CIF" . $cifGroupName . $cifModuleName . "_";

	# Draw the CIF dialog box
	CifDraw($cifGroupName, $cifModuleName, "Race Grid", "DoCifInfo");

	# Set various vars for GUI size and location
	$hcOrigT = $CifOrigT+1;			# Top edge of main content window
	$hcOrigL = $CifOrigL+1;	# Left edge of main content window
	$hcOrigR = $CifOrigL+50;

	# Left hand titles
	openPrivButton ($DialogPrefix . "luser",$hcOrigL,$hcOrigT,27,$CifRowHeight,1,-1,99,"Nickname");
	openPrivButton ($DialogPrefix . "lweight",$hcOrigL+27,$hcOrigT,11,$CifRowHeight,1,-1,35,"Weight");
	openPrivButton ($DialogPrefix . "lintake",$hcOrigL+38,$hcOrigT,11,$CifRowHeight,1,-1,35,"Intake");

	# Right hand titles
	openPrivButton ($DialogPrefix . "ruser",$hcOrigR,$hcOrigT,27,$CifRowHeight,1,-1,99,"Nickname");
	openPrivButton ($DialogPrefix . "rweight",$hcOrigR+27,$hcOrigT,11,$CifRowHeight,1,-1,35,"Weight");
	openPrivButton ($DialogPrefix . "rintake",$hcOrigR+38,$hcOrigT,11,$CifRowHeight,1,-1,35,"Intake");

#	dumpvar($RaceGridOrder);
	
	# Cycle through the current RaceGridOrder array to get the display
	FOR ( $i=0; $i < 32; $i = $i + 1 )
		$uName = GetPlayerVarByPLID( ToNum($RaceGridOrder[$i]), "UserName");
		$uNick = GetPlayerVar($uName,"NickName");
		$Pref = $DialogPrefix . $i . "_";

		$IsOdd = $i & 1;
		IF ($IsOdd == 0)	# Check if we are on left or right side
		THEN
			$origRow = $hcOrigT + $CifRowHeight + (Round($i / 2,0) * $CifRowHeight);
			$origCol = $hcOrigL;
		ELSE
			$origCol = $hcOrigR;
		ENDIF

		# Set the header row and display different info for Admins vs Players
		openPrivButton ($Pref . "hUser",$origCol,$origRow,27,$CifRowHeight,1,-1,96,"^7". $uNick);
		IF ( UserIsAdmin( GetCurrentPlayerVar("UserName") ) == 1 )
		THEN
			openPrivButton ($Pref . "wCurr",$origCol+27,$origRow,8,$CifRowHeight,1,-1,32,GetPlayerVar($uName,"P_Mass") ."/^3" . GetPlayerVar($uName,"H_Mass"));
			openPrivButton ($Pref . "wMore",$origCol+35,$origRow,3,3,1,-1,32,"^1+",DoHandicapper_wMore);
			openPrivButton ($Pref . "wLess",$origCol+35,$origRow+3,3,3,1,-1,32,"^2-",DoHandicapper_wLess);
			openPrivButton ($Pref . "iCurr",$origCol+38,$origRow,8,$CifRowHeight,1,-1,32,GetPlayerVar($uName,"P_Tres") ."/^3" . GetPlayerVar($uName,"H_Tres"));
			openPrivButton ($Pref . "iMore",$origCol+46,$origRow,3,3,1,-1,32,"^1+",DoHandicapper_iMore);
			openPrivButton ($Pref . "iLess",$origCol+46,$origRow+3,3,3,1,-1,32,"^2-",DoHandicapper_iLess);
		ELSE
			openPrivButton ($Pref . "wCurr",$origCol+27,$origRow,11,$CifRowHeight,1,-1,32,GetPlayerVar($uName,"P_Mass") ."/^3" . GetPlayerVar($uName,"H_Mass"));
			openPrivButton ($Pref . "iCurr",$origCol+38,$origRow,11,$CifRowHeight,1,-1,32,GetPlayerVar($uName,"P_Tres") ."/^3" . GetPlayerVar($uName,"H_Tres"));
		ENDIF
	ENDFOR
	
	IF ( UserIsAdmin( GetCurrentPlayerVar("UserName") ) == 1 )
	THEN
		# Draw the Load/Save/Reset buttons
		CifCmdButton( 1, "^7Load", DoHandicapper_Load );
		CifCmdButton( 2, "^7Save", DoHandicapper_Save );
		CifCmdButton( 3, "^7Reset", DoHandicapper_Reset );
	ENDIF
EndSub

